@@ -9,11 +9,10 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expressi
  *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  * 
  */
-public class C_Sum extends C_Expression {
+public class C_Sum extends C_AggregationExpression {
 
 	private static final long serialVersionUID = 1365651146183648884L;
 	protected String id = "Sum";
-	protected C_Expression argument;
 
 	public C_Sum() {
 
@@ -25,33 +24,24 @@ public class C_Sum extends C_Expression {
 	 */
 	public C_Sum(C_Expression argument) {
 		this.argument = argument;
-
+		if (argument != null) {
+			this.readableExpression = "Sum(" + argument.getReadableExpression()
+					+ ")";
+		}
 	}
 
 	public C_OperatorType getOperator() {
 		return C_OperatorType.SUM;
 	}
 
-	public String getReturnedDataType() {
-		return "DataType";
-	}
-
 	@Override
 	public String getId() {
 		return id;
 	}
 
-	public C_Expression getArgument() {
-		return argument;
-	}
-
-	public void setArgument(C_Expression argument) {
-		this.argument = argument;
-	}
-
 	@Override
 	public String toString() {
-		return "C_Sum [id=" + id + ", argument=" + argument + "]";
+		return "Sum [id=" + id + ", argument=" + argument + "]";
 	}
 
 }
