@@ -10,22 +10,25 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expressi
  * 
  */
 public class C_Concat extends C_Expression {
-	
+
 	private static final long serialVersionUID = 5871179766613405166L;
 	protected String id = "Concat";
 	protected C_Expression leftArgument;
 	protected C_Expression rightArgument;
 
-	public C_Concat(){
+	public C_Concat() {
 		super();
 	}
-	
-	
-	public C_Concat(C_Expression leftArgument,
-			C_Expression rightArgument) {
+
+	public C_Concat(C_Expression leftArgument, C_Expression rightArgument) {
 		super();
 		this.leftArgument = leftArgument;
 		this.rightArgument = rightArgument;
+		if (leftArgument != null && rightArgument != null) {
+			this.readableExpression = "Concat("
+					+ leftArgument.getReadableExpression() + ","
+					+ rightArgument.getReadableExpression() + ")";
+		}
 	}
 
 	public C_OperatorType getOperator() {
@@ -35,7 +38,7 @@ public class C_Concat extends C_Expression {
 	public String getReturnedDataType() {
 		return "Text";
 	}
-	
+
 	@Override
 	public String getId() {
 		return id;
@@ -57,13 +60,10 @@ public class C_Concat extends C_Expression {
 		this.rightArgument = rightArgument;
 	}
 
-
 	@Override
 	public String toString() {
-		return "C_Concat [id=" + id + ", leftArgument=" + leftArgument
+		return "Concat [id=" + id + ", leftArgument=" + leftArgument
 				+ ", rightArgument=" + rightArgument + "]";
 	}
 
-	
-
 }
