@@ -10,26 +10,30 @@ public class C_Range extends C_Leaf implements C_MultivaluedExpression {
 	protected TD_Value minimum;
 	protected TD_Value maximum;
 
-	public C_Range(){
-		
+	public C_Range() {
+
 	}
-	
+
 	public C_Range(TD_Value minimum, TD_Value maximum) {
 		this.minimum = minimum;
 		this.maximum = maximum;
+		if (minimum != null && maximum != null) {
+			this.readableExpression = "Range("
+					+ minimum.getReadableExpression() + ","
+					+ maximum.getReadableExpression() + ")";
+		}
 	}
-	
+
 	@Override
 	public String getId() {
 		return id;
 	}
-	
+
 	@Override
 	public String getIdMulti() {
 		return id;
 	}
 
-
 	public TD_Value getMinimum() {
 		return minimum;
 	}
@@ -46,6 +50,11 @@ public class C_Range extends C_Leaf implements C_MultivaluedExpression {
 		this.maximum = maximum;
 	}
 
+	@Override
+	public String getReadableMultivaluedString() {
+		return readableExpression;
+	}
+	
 	@Override
 	public String toString() {
 		return "Range [id=" + id + ", minimum=" + minimum + ", maximum="
